==> GeneticsBase_1.0.0.tar.gz: GeneticsBase/R/print.LD.R <==
## $Id: print.LD.R 1110 2006-11-21 22:13:37Z warnes $

## works for both LD and LDband!

summary.LD <- function(object,
                       which=c("D", "D'", "r", "R^2", "X^2",
                         "P-value", "LOD", "n"),
                       rowsep,
                       digits=3, ...)
  {

    if(missing(rowsep))
      if(length(which)==1)
        rowsep <- NULL
      else
        rowsep <- " "

    if(is.null(rowsep))
      blank <- NULL
    else
      blank <- matrix(rowsep, ncol=ncol(object@"D"), nrow=nrow(object@"D"))

    test <- function(name, val, p=FALSE, int=FALSE)
      {
        ret <- if (name %in% which) val else NULL
        if(is.numeric(ret))
          if(p)
            ret <- matrix(format.pval(ret, digits),ncol=ncol(val))
          else if(int)
            ret <- matrix(format(as.integer(ret)), ncol=ncol(val))
          else
            ret <- format(round(ret, digits))
        ret
      }


    tab <- interleave(
                      "D"       = test('D',       object@D),
                      "D'"      = test("D'",      object@"D'"),
                      "Corr."   = test("r",       object@"r"),
                      "R^2"     = test("R^2",     object@"R^2"),                      
                      "LD X^2"  = test("X^2",     object@"X^2", int=TRUE),
                      "P-value" = test("P-value", object@"P-value", p=TRUE),
                      "LOD"       = test('LOD',       object@"LOD"),
                      "n"       = test('n',       object@"n"),
                      " "=blank,
                      sep=" "
                      )

    tab[unlist(grep("NA",tab))] <- NA

    ## Make separator row names unique by using an increasing number of spaces.
    ## This helps to avoid issues in html() and latex()
    blankname <- " "
    for( i in 1:nrow(tab))
      if( all( unlist(strsplit(rownames(tab)[i],''))==" " ) )
        {
          rownames(tab)[i] <- blankname
          blankname <- paste(blankname, " ", sep='')
        }

    statlist <- which[ ! (which %in% c("P-value", "n", " ") ) ]
    statlist[statlist=="X^2"] <- "X\\^2"
    statlist[statlist=="R^2"] <- "R\\^2"

    retval <- list()

    retval$tab <- tab
    retval$statlist <- statlist
    retval$which <- which
    retval$object <- object
    
    retval
  }
  

show.LD <- function(object)
  {
    digits<-3
    show.all<-TRUE
    x <- summary.LD(object, digits=digits)

    tab <- x$tab
    statlist <- x$statlist
    which <- x$which    
    object <- x$object
    
    formatlist <- sapply( statlist, function(object) grep(object, rownames(tab) ) )
    formatlist <- unique(sort(unlist(formatlist)))
    pvallist   <- grep( "P-value", rownames(tab) )
    
    tab[formatlist,] <- formatC(as.numeric(tab[formatlist,]), digits=digits,
                                format="f")
    tab[pvallist,] <- apply(object@"P-value", c(1,2),
                            function(object)trim(format.pval(object, digits=digits)))
    
    tab[trim(tab)=="NA"] <- NA

    if(!show.all)
      {
        ## drop blank row/column
        entrylen <- nrow(tab)/nrow(object@n)
        tab <- tab[1:(nrow(tab) - entrylen),-1]
      }

    
  cat("\n")
  cat("-----------\n")
  cat("Pairwise LD\n")
  cat("-----------\n")

  print.default(unclass(tab), digits=digits, quote=FALSE,
                na.print="    ", right=TRUE) 
        
  cat("\n")

  invisible(tab)
}

setMethod("show", "LD",  show.LD)
setMethod("show", "LDband",  show.LD)
setMethod("show", "LDdist",  show.LD)


head.LD <- function (x,
                     n=6,
                     ...)
{
  nr <- min(n, nrow(x@D))
  retval <- x
  for(element in c("D", "D'", "r", "R^2", "X^2","P-value", "LOD", "n"))
    slot(retval, element) <- slot(retval,element)[1:nr,,drop=FALSE]
  show(retval)
  invisible(retval)
}

setGeneric("head", function(x, ...)
           standardGeneric("head"))

setMethod("head", "LD", head.LD)
setMethod("head", "LDband", head.LD)
setMethod("head", "LDdist", head.LD)

tail.LD <- function (x,
                     n=6,
                     ...)
{
  nr <- max(1, nrow(x@D)-n+1)
  retval <- x
  for(element in c("D", "D'", "r", "R^2", "X^2","P-value", "LOD", "n"))
    slot(retval, element) <- slot(retval,element)[nr:nrow(x@D),,drop=FALSE]
  show(retval)
  invisible(retval)
}


setGeneric("tail", function(x, ...)
           standardGeneric("tail"))

setMethod("tail", "LD", tail.LD)
setMethod("tail", "LDband", tail.LD)
setMethod("tail", "LDdist", tail.LD)

left.LD <- function (x,
                     n=6,
                     ...)
{
  nr <- min(n, ncol(x@D))
  retval <- x
  for(element in c("D", "D'", "r", "R^2", "X^2","P-value", "n"))
    slot(retval, element) <- slot(retval,element)[,1:nr,drop=FALSE]
  show(retval)
  invisible(retval)
}

if (!isGeneric("left"))
  setGeneric("left", function(x, ...)
             standardGeneric("left"))


setMethod("left", "LD", left.LD)
setMethod("left", "LDband", left.LD)
setMethod("left", "LDdist", left.LD)

right.LD <- function (x,
                     n=6,
                     ...)
{
  nr <- max(1, ncol(x@D)-n+1)
  retval <- x
  for(element in c("D", "D'", "r", "R^2", "X^2","P-value", "LOD", "n"))
    slot(retval, element) <- slot(retval,element)[,nr:ncol(x@D),drop=FALSE]
  show(retval)
  invisible(retval)
}

if (!isGeneric("right"))
  setGeneric("right", function(x, ...)
             standardGeneric("right"))

setMethod("right", "LD", right.LD)
setMethod("right", "LDband", right.LD)
setMethod("right", "LDdist", right.LD)


html.LD <- function(x, filename="", digits=3, ...)
  {
    library(xtable) ## load xtable library

    tmp <- summary.LD(x, digits=digits)
    tab <- data.frame(tmp$tab, row.names=1:nrow(tmp$tab))
    attr(tab,"row.names") <- row.names(tmp$tab)
    xtab <- xtable(
                   tab,
                   label='tabbig',
                   quote=FALSE,
                   caption=x$footer,
                   digits=rep(digits, ncol(tmp$tab)+1),
                   ...
                   )
    
    print.xtable(
                 xtab,
                 type="html",
                 file=filename,
                 ...
             )
  }

if (!isGeneric("html"))
  setGeneric("html", function(x, filename='', ...)
             standardGeneric("html"))
setMethod("html", "LD", html.LD)

latex.LD <- function(x, filename='', digits=3, ...)
  {
    library(xtable) ## load xtable library

    tmp <- summary.LD(x, digits=digits)
    tab <- data.frame(tmp$tab, row.names=1:nrow(tmp$tab))
    attr(tab,"row.names") <- gsub("X\\^2", "\\$\\\\chi^2\\$", row.names(tmp$tab))
    attr(tab,"row.names") <- gsub("R\\^2", "\\$R^2\\$",       row.names(tab))
    
    xtab <- xtable(
                   tab,
                   label='tabbig',
                   quote=FALSE,
                   caption=gsub("%","\\\\%", x$footer),
                   ...
                   )
    
    print.xtable(
                 xtab,
                 type="latex",
                 file=filename,
                 ...
             )
  }


if (!isGeneric("latex"))
  setGeneric("latex", function(x, filename='', ...)
             standardGeneric("latex"))
setMethod("latex", "LD", latex.LD)

==> GeneticsBase_1.12.0.tar.gz: GeneticsBase/R/print.LD.R <==
## $Id: print.LD.R 1223 2007-05-26 16:20:28Z warnes $

## works for both LD and LDband!

summary.LD <- function(object,
                       which=c("D", "D'", "r", "R^2", "X^2",
                         "P-value", "LOD", "n"),
                       rowsep,
                       digits=3, ...)
  {

    if(missing(rowsep))
      if(length(which)==1)
        rowsep <- NULL
      else
        rowsep <- " "

    if(is.null(rowsep))
      blank <- NULL
    else
      blank <- matrix(rowsep, ncol=ncol(object@"D"), nrow=nrow(object@"D"))

    test <- function(name, val, p=FALSE, int=FALSE)
      {
        ret <- if (name %in% which) val else NULL
        if(is.numeric(ret))
          if(p)
            ret <- matrix(format.pval(ret, digits),ncol=ncol(val))
          else if(int)
            ret <- matrix(format(as.integer(ret)), ncol=ncol(val))
          else
            ret <- format(round(ret, digits))
        ret
      }


    tab <- interleave(
                      "D"       = test('D',       object@D),
                      "D'"      = test("D'",      object@"D'"),
                      "Corr."   = test("r",       object@"r"),
                      "R^2"     = test("R^2",     object@"R^2"),                      
                      "LD X^2"  = test("X^2",     object@"X^2", int=TRUE),
                      "P-value" = test("P-value", object@"P-value", p=TRUE),
                      "LOD"       = test('LOD',       object@"LOD"),
                      "n"       = test('n',       object@"n"),
                      " "=blank,
                      sep=" "
                      )

    tab[unlist(grep("NA",tab))] <- NA

    ## Make separator row names unique by using an increasing number of spaces.
    ## This helps to avoid issues in html() and latex()
    blankname <- " "
    for( i in 1:nrow(tab))
      if( all( unlist(strsplit(rownames(tab)[i],''))==" " ) )
        {
          rownames(tab)[i] <- blankname
          blankname <- paste(blankname, " ", sep='')
        }

    statlist <- which[ ! (which %in% c("P-value", "n", " ") ) ]
    statlist[statlist=="X^2"] <- "X\\^2"
    statlist[statlist=="R^2"] <- "R\\^2"

    retval <- list()

    retval$tab <- tab
    retval$statlist <- statlist
    retval$which <- which
    retval$object <- object
    
    retval
  }
  

show.LD <- function(object)
  {
    digits<-3
    show.all<-TRUE
    x <- summary.LD(object, digits=digits)

    tab <- x$tab
    statlist <- x$statlist
    which <- x$which    
    object <- x$object
    
    formatlist <- sapply( statlist, function(object) grep(object, rownames(tab) ) )
    formatlist <- unique(sort(unlist(formatlist)))
    pvallist   <- grep( "P-value", rownames(tab) )
    
    tab[formatlist,] <- formatC(as.numeric(tab[formatlist,]), digits=digits,
                                format="f")
    tab[pvallist,] <- apply(object@"P-value", c(1,2),
                            function(object)trim(format.pval(object, digits=digits)))
    
    tab[trim(tab)=="NA"] <- NA

    if(!show.all)
      {
        ## drop blank row/column
        entrylen <- nrow(tab)/nrow(object@n)
        tab <- tab[1:(nrow(tab) - entrylen),-1,drop=FALSE]
      }

    
  cat("\n")
  cat("-----------\n")
  cat("Pairwise LD\n")
  cat("-----------\n")

  print.default(unclass(tab), digits=digits, quote=FALSE,
                na.print="    ", right=TRUE) 
        
  cat("\n")

  invisible(tab)
}

setMethod("show", "LD",  show.LD)
setMethod("show", "LDband",  show.LD)
setMethod("show", "LDdist",  show.LD)


head.LD <- function (x,
                     n=6,
                     ...)
{
  nr <- min(n, nrow(x@D))
  retval <- x
  for(element in c("D", "D'", "r", "R^2", "X^2","P-value", "LOD", "n"))
    slot(retval, element) <- slot(retval,element)[1:nr,,drop=FALSE]
  show(retval)
  invisible(retval)
}

setGeneric("head", function(x, ...)
           standardGeneric("head"))

setMethod("head", "LD", head.LD)
setMethod("head", "LDband", head.LD)
setMethod("head", "LDdist", head.LD)

tail.LD <- function (x,
                     n=6,
                     ...)
{
  nr <- max(1, nrow(x@D)-n+1)
  retval <- x
  for(element in c("D", "D'", "r", "R^2", "X^2","P-value", "LOD", "n"))
    slot(retval, element) <- slot(retval,element)[nr:nrow(x@D),,drop=FALSE]
  show(retval)
  invisible(retval)
}


setGeneric("tail", function(x, ...)
           standardGeneric("tail"))

setMethod("tail", "LD", tail.LD)
setMethod("tail", "LDband", tail.LD)
setMethod("tail", "LDdist", tail.LD)

left.LD <- function (x,
                     n=6,
                     ...)
{
  nr <- min(n, ncol(x@D))
  retval <- x
  for(element in c("D", "D'", "r", "R^2", "X^2","P-value", "n"))
    slot(retval, element) <- slot(retval,element)[,1:nr,drop=FALSE]
  show(retval)
  invisible(retval)
}

if (!isGeneric("left"))
  setGeneric("left", function(x, ...)
             standardGeneric("left"))


setMethod("left", "LD", left.LD)
setMethod("left", "LDband", left.LD)
setMethod("left", "LDdist", left.LD)

right.LD <- function (x,
                     n=6,
                     ...)
{
  nr <- max(1, ncol(x@D)-n+1)
  retval <- x
  for(element in c("D", "D'", "r", "R^2", "X^2","P-value", "LOD", "n"))
    slot(retval, element) <- slot(retval,element)[,nr:ncol(x@D),drop=FALSE]
  show(retval)
  invisible(retval)
}

if (!isGeneric("right"))
  setGeneric("right", function(x, ...)
             standardGeneric("right"))

setMethod("right", "LD", right.LD)
setMethod("right", "LDband", right.LD)
setMethod("right", "LDdist", right.LD)


html.LD <- function(x, filename="", digits=3, ...)
  {
    library(xtable) ## load xtable library

    tmp <- summary.LD(x, digits=digits)
    tab <- data.frame(tmp$tab, row.names=1:nrow(tmp$tab))
    attr(tab,"row.names") <- row.names(tmp$tab)
    xtab <- xtable(
                   tab,
                   label='tabbig',
                   quote=FALSE,
                   #caption=x$footer,
                   caption=NULL,
                   digits=rep(digits, ncol(tmp$tab)+1),
                   ...
                   )
    
    #print.xtable(
    print(
                 xtab,
                 type="html",
                 file=filename,
                 ...
             )
  }

if (!isGeneric("html"))
  setGeneric("html", function(x, filename='', ...)
             standardGeneric("html"))
setMethod("html", "LD", html.LD)

latex.LD <- function(x, filename='', digits=3, ...)
  {
    library(xtable) ## load xtable library

    tmp <- summary.LD(x, digits=digits)
    tab <- data.frame(tmp$tab, row.names=1:nrow(tmp$tab))
    attr(tab,"row.names") <- gsub("X\\^2", "\\$\\\\chi^2\\$", row.names(tmp$tab))
    attr(tab,"row.names") <- gsub("R\\^2", "\\$R^2\\$",       row.names(tab))
    
    xtab <- xtable(
                   tab,
                   label='tabbig',
                   quote=FALSE,
                   #caption=gsub("%","\\\\%", x$footer),
                   caption=NULL,
                   ...
                   )
    
    #print.xtable(
    print(
                 xtab,
                 type="latex",
                 file=filename,
                 ...
             )
  }


if (!isGeneric("latex"))
  setGeneric("latex", function(x, filename='', ...)
             standardGeneric("latex"))
setMethod("latex", "LD", latex.LD)
